#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-06-16
# File  : checkpoint_ha_status.py (wato)
#

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    MonitoringState,
    DropdownChoice,
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_checkpoint_ha_status():
    return Dictionary(
        elements=[
            ('state_not_installed',
                MonitoringState(
                    title=_('State not installed'),
                    help=_('Monitoring state if the HA module is not installed.'),
                    default_value=2
                )),

            ('expected_ha_state',
             DropdownChoice(
                 title=_('Select the expected HA state'),
                 help=_('The expected HA sate reported by the device'),
                 choices=[
                     ('active', _('Active')),
                     ('standby', _('Standby')),
                 ])),

            ('state_if_not_expected',
                MonitoringState(
                    title=_('State on not expected HA State'),
                    help=_('Monitoring state if the device is not in the expected HA state.'),
                    default_value=1
                )),
            ('state_not_started',
                MonitoringState(
                    title=_('State not started'),
                    help=_('Monitoring state if the HA module is not started.'),
                    default_value=2
                )),
            ('state_blocking',
                MonitoringState(
                    title=_('State blocking not OK'),
                    help=_('Monitoring state if the Blocking state is not OK.'),
                    default_value=2
                )),

            ('state_problem',
                MonitoringState(
                    title=_('State on problem'),
                    help=_('Monitoring state if the HA module has a problem.'),
                    default_value=2
                )),                                                                
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name='checkpoint_ha_status',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_ha_status,
        title=lambda: _('Check Point HA Status'),
    ))
